pub struct VariantBuilder { /* private fields */ }Expand description
Builder for a single enum variant.
Implementations
Sourceimpl VariantBuilder
impl VariantBuilder
Sourcepub fn field(self, name: impl Into<String>) -> FieldBuilder<Self>
pub fn field(self, name: impl Into<String>) -> FieldBuilder<Self>
Starts a named field inside the variant.
Sourcepub fn unnamed(self) -> FieldBuilder<Self>
pub fn unnamed(self) -> FieldBuilder<Self>
Starts an unnamed field inside the variant.
Sourcepub fn value(self, value: impl Into<String>) -> Self
pub fn value(self, value: impl Into<String>) -> Self
Sets the value for the most recently added annotation.
Sourcepub fn finish_variant(self) -> VariantDefBuilder
pub fn finish_variant(self) -> VariantDefBuilder
Finishes the variant and returns to the enclosing variant builder.