pub struct MetaType { /* private fields */ }Expand description
Type-erased handle to a concrete TypeInfo implementation.
Implementations
Sourceimpl MetaType
impl MetaType
Sourcepub fn type_decl(&self, registry: &mut Registry) -> TypeDecl
pub fn type_decl(&self, registry: &mut Registry) -> TypeDecl
Produces the use-site type declaration for the represented type.
Sourcepub fn type_def(&self, registry: &mut Registry) -> Option<Type>
pub fn type_def(&self, registry: &mut Registry) -> Option<Type>
Produces the stored named definition for the represented type, if any.
Sourcepub fn module_path(&self) -> &'static str
pub fn module_path(&self) -> &'static str
Returns the module path associated with the represented named type.